# Quickstart

## Installation

The latest official release of BDTsim can be installed using `pip`:

```
pip install bdtsim
```

If you want to install a more recent version,
it is also possible to install BDTsim directly from the Git repository:

```
pip install git+https://gitlab.com/MatthiasLohr/bdtsim
```

Please note that this version is still in development and may be unstable.
However, if you experience errors or bugs, please report to our [Issue Tracker](https://gitlab.com/MatthiasLohr/bdtsim/-/issues).


## Usage

The `bdtsim` package provides a command `bdtsim` for running the simulations.
Check `bdtsim -h` for a list of supported sub-commands or take a look at our [command documentation page](commands.md).
